@@ -1,8 +1,9 @@
 from authlib.consts import default_json_headers
+from ..requests import OAuth2Request
 from ..errors import InvalidRequestError
 
 
-class BaseGrant(object):
+class BaseGrant:
     #: Allowed client auth methods for token endpoint
     TOKEN_ENDPOINT_AUTH_METHODS = ['client_secret_basic']
 
@@ -15,7 +16,7 @@ class BaseGrant(object):
     # https://tools.ietf.org/html/rfc4627
     TOKEN_RESPONSE_HEADER = default_json_headers
 
-    def __init__(self, request, server):
+    def __init__(self, request: OAuth2Request, server):
         self.prompt = None
         self.redirect_uri = None
         self.request = request
@@ -92,7 +93,7 @@ class BaseGrant(object):
             hook(self, *args, **kwargs)
 
 
-class TokenEndpointMixin(object):
+class TokenEndpointMixin:
     #: Allowed HTTP methods of this token endpoint
     TOKEN_ENDPOINT_HTTP_METHODS = ['POST']
 
@@ -100,7 +101,7 @@ class TokenEndpointMixin(object):
     GRANT_TYPE = None
 
     @classmethod
-    def check_token_endpoint(cls, request):
+    def check_token_endpoint(cls, request: OAuth2Request):
         return request.grant_type == cls.GRANT_TYPE and \
                request.method in cls.TOKEN_ENDPOINT_HTTP_METHODS
 
@@ -111,16 +112,16 @@ class TokenEndpointMixin(object):
         raise NotImplementedError()
 
 
-class AuthorizationEndpointMixin(object):
+class AuthorizationEndpointMixin:
     RESPONSE_TYPES = set()
     ERROR_RESPONSE_FRAGMENT = False
 
     @classmethod
-    def check_authorization_endpoint(cls, request):
+    def check_authorization_endpoint(cls, request: OAuth2Request):
         return request.response_type in cls.RESPONSE_TYPES
 
     @staticmethod
-    def validate_authorization_redirect_uri(request, client):
+    def validate_authorization_redirect_uri(request: OAuth2Request, client):
         if request.redirect_uri:
             if not client.check_redirect_uri(request.redirect_uri):
                 raise InvalidRequestError(
@@ -143,5 +144,5 @@ class AuthorizationEndpointMixin(object):
     def validate_authorization_request(self):
         raise NotImplementedError()
 
-    def create_authorization_response(self, redirect_uri, grant_user):
+    def create_authorization_response(self, redirect_uri: str, grant_user):
         raise NotImplementedError()
